#!/usr/bin/env python
# coding: utf-8

# In[8]:


import spacy
sp_d = spacy.load('de_core_news_sm')
import nltk
nltk.download('stopwords')
from nltk.corpus import stopwords
stop_words = set(stopwords.words('german'))


# In[12]:


# ADD FURTHER STOP WORDS

stop_words.add('agentur')
stop_words.add('emission')
stop_words.add('art')
stop_words.add('geehrte')
stop_words.add('frau')
stop_words.add('schreiben')
stop_words.add('vielen')
stop_words.add('dank')

#personalize stopwords
stop_words.add('fur')
stop_words.add('fuer')
stop_words.add('weitere')
stop_words.add('eng')
stop_words.add('tragen')


stop_words.add('art')
stop_words.add('arten')
stop_words.add('artikel')

stop_words.add('unterstuetzt')
stop_words.add('unterstuetzen')
stop_words.add('unterstuetzung')

stop_words.add('vorlage')
stop_words.add('vorschlag')

stop_words.add('stellungnahme')
stop_words.add('installation')
stop_words.add('energien')
stop_words.add('energie')
stop_words.add('revision')

stop_words.add('erlaeuternden')
stop_words.add('erlaeuterungen')

#political institutional 
stop_words.add('regierungsrat')
stop_words.add('nationalrat')
stop_words.add('bundesrat')
stop_words.add('bundesrates')
stop_words.add('bundespraesiden')
stop_words.add('bund')
stop_words.add('kantone')
stop_words.add('kanton')
stop_words.add('standorte')
stop_words.add('organisationen')
stop_words.add('gemeinden')

stop_words.add('parlament')
stop_words.add('gesetzgeber')
stop_words.add('schweizerisch')
stop_words.add('volksabstimmung')
stop_words.add('behoerde')
stop_words.add('bundesamt')
stop_words.add('gesetzlichen')
stop_words.add('programme')
stop_words.add('gesetzes')
stop_words.add('aenderungen')
stop_words.add('revidiert')
stop_words.add('gesetzlich')
stop_words.add('eintrag')
stop_words.add('schweiz')
stop_words.add('eu')
stop_words.add('bafu')
stop_words.add('svp')
stop_words.add('staenderat')


#basic stopwords
stop_words.add('wurde')
stop_words.add('werden')
stop_words.add('waere')
stop_words.add('wird')
stop_words.add('wuerden')
stop_words.add('koennte')
stop_words.add('koennten')
stop_words.add('koennen')

stop_words.add('muessen')
stop_words.add('muessten')
stop_words.add('muess')
stop_words.add('sind')
stop_words.add('ist')
stop_words.add('unserem')

stop_words.add('schreiben')

#abbreviations
stop_words.add('vgln')
stop_words.add('kwp')
stop_words.add('stellungnahme')
stop_words.add('im')
stop_words.add('mw')
stop_words.add('anlagen')
stop_words.add('anlage')
stop_words.add('schweiz')
stop_words.add('schweizer')
stop_words.add('bericht')
stop_words.add('erlaeuternden')
stop_words.add('erlaeuternder')
stop_words.add('insbesondere')
stop_words.add('abs')
stop_words.add('absatz')


stop_words.add('erneuerbar')
stop_words.add('erneuerbaren')
stop_words.add('nachhaltig')

stop_words.add('artikel')
stop_words.add('absatz')
stop_words.add('abs')
stop_words.add('massnahmen')
stop_words.add('gemaess')
stop_words.add('verordnung')
stop_words.add('gesetz')
stop_words.add('gesetze')
stop_words.add('antrag')
stop_words.add('coverordnung')
stop_words.add('cverordnung')
stop_words.add('kantonalen')
stop_words.add('anpassung')
stop_words.add('ebene')
stop_words.add('grundlage')
stop_words.add('dokument')
stop_words.add('antraeg')
stop_words.add('august')
stop_words.add('stiftung')
stop_words.add('verfuegung')
stop_words.add('kommentar')
stop_words.add('cogesetz')
               
stop_words.add('fuer')
stop_words.add('coemission')
stop_words.add('projekte')

stop_words.add('eingeladen')
stop_words.add('deshalb')
stop_words.add('bereits')
stop_words.add('prozent')
stop_words.add('anhang')
stop_words.add('insbesondere')
stop_words.add('mehr')
stop_words.add('covo')
stop_words.add('ueber')
stop_words.add('bfe')
stop_words.add('aufgrund')
stop_words.add('jahren')
stop_words.add('jedoch')
stop_words.add('wuerde')
stop_words.add('uf')
stop_words.add('bzw')
stop_words.add('sowie')
stop_words.add('wirkung')
stop_words.add('wltp')
stop_words.add('gesuch')
stop_words.add('beim')
stop_words.add('referenzjahr')
stop_words.add('rat')
stop_words.add('umsetzung')
stop_words.add('ansicht')
stop_words.add('tonne')
stop_words.add('rund')
stop_words.add('totalrevision')
stop_words.add('bst')
stop_words.add('sollen')


# In[14]:


stop_words.add('hoeheren')
stop_words.add('klimaziel')

stop_words.add('genannt')
stop_words.add('durchgefuehren')
stop_words.add('erhebung')
stop_words.add('zusammen')
stop_words.add('ausschoepfen')
stop_words.add('ausschließen')
stop_words.add('branche')
stop_words.add('brauchen')
stop_words.add('definition')
stop_words.add('klimawandel')
stop_words.add('umwelt')
stop_words.add('wa')
stop_words.add('kompetenz')

stop_words.add('erstellen')
stop_words.add('ersetzen')
stop_words.add('vernetzen')
stop_words.add('grosse')
stop_words.add('sicher')
stop_words.add('dennoch')
stop_words.add('gesetzgebung')
stop_words.add('verfuegen')
stop_words.add('ermoeglicht')
stop_words.add('beschraenken')
stop_words.add('vorrang')
stop_words.add('betroffen')
stop_words.add('unserer_sicht')
stop_words.add('entstehen')
stop_words.add('verrechnen')
stop_words.add('dazu_gehoert')
stop_words.add('aufzeigen')
stop_words.add('festlegung')
stop_words.add('kurz')
stop_words.add('kyoto_periode')
stop_words.add('erweisen')
stop_words.add('planen')

stop_words.add('erfasst')
stop_words.add('saemtlich')
stop_words.add('endk')
stop_words.add('zunehmend')
stop_words.add('denkbar')
stop_words.add('begrenzen')
stop_words.add('unterschied')
stop_words.add('umfassend')
stop_words.add('nachfolgend')
stop_words.add('aufhebung')
stop_words.add('flugplatzhalter')
stop_words.add('gruend')
stop_words.add('ueberwachung')
stop_words.add('etwa')

stop_words.add('schafft')
stop_words.add('weder')
stop_words.add('kg')
stop_words.add('hev')
stop_words.add('sava')
stop_words.add('cdr')
stop_words.add('usw')
stop_words.add('wer')
stop_words.add('statt')
stop_words.add('rt_bs')
stop_words.add('punkte')
stop_words.add('vorgenommen')
stop_words.add('vorgesehener')

stop_words.add('zustaendige')
stop_words.add('stehen')
stop_words.add('gesamte')
stop_words.add('besteht')
stop_words.add('sei')
stop_words.add('denen')
stop_words.add('entfaellt')
stop_words.add('kommt')
stop_words.add('stadt')
stop_words.add('liste')
stop_words.add('fr')
stop_words.add('aktuell')
stop_words.add('derzeit')
stop_words.add('notwendig')
stop_words.add('aschen')
stop_words.add('zuerich')
stop_words.add('verschiedenen')
stop_words.add('frage')
stop_words.add('teil')
stop_words.add('wichtige')
stop_words.add('aufgenommen')
stop_words.add('fest')
stop_words.add('hintergrund')
stop_words.add('kilometer')

stop_words.add('hierzu')
stop_words.add('namentlich')
stop_words.add('einstellung')
stop_words.add('womit')
stop_words.add('allenfalls')
stop_words.add('durchgefuehrter')
stop_words.add('betrifft')
stop_words.add('dereinst')
stop_words.add('modelle')
stop_words.add('koenn')
stop_words.add('sinn')
stop_words.add('login')
stop_words.add('beispielsweise')
stop_words.add('daten')
stop_words.add('gleich')
stop_words.add('folgen')
stop_words.add('folgend')
stop_words.add('geben')
stop_words.add('zeigen')
stop_words.add('umsetzen')
stop_words.add('zeit')
stop_words.add('bekannt')
stop_words.add('verwenden')
stop_words.add('vornehmen')
stop_words.add('teilnehmer')
stop_words.add('erzielen')
stop_words.add('erzielt')
stop_words.add('geltend')
stop_words.add('bringen')
stop_words.add('zusaetzlich')

stop_words.add('droht_was')
stop_words.add('ja')
stop_words.add('ue_bertragung')
stop_words.add('eingeraeumen')
stop_words.add('schlag')
stop_words.add('hoehe')
stop_words.add('durchschnitt')
stop_words.add('betroffener')
stop_words.add('betreffen')
stop_words.add('vollstaendig')
stop_words.add('uebrig')
stop_words.add('moechen')
stop_words.add('hoch')
stop_words.add('umsetzen')
stop_words.add('gross')
stop_words.add('gesamt')
stop_words.add('waern')
stop_words.add('gut')
stop_words.add('vorliegend')
stop_words.add('aufnehmen')
stop_words.add('sehen')
stop_words.add('setzen')
stop_words.add('frei')
stop_words.add('klein')
stop_words.add('erfolgen')
stop_words.add('festlegen')
stop_words.add('vorgesehen')
stop_words.add('waern')
stop_words.add('gelegenheit')
stop_words.add('begruenden')
stop_words.add('einzeln')
stop_words.add('pro_kilometer')
stop_words.add('erhalten')
stop_words.add('droht_was')
stop_words.add('franke')
stop_words.add('sehen')
stop_words.add('fehlend')
stop_words.add('klar')
stop_words.add('entsprechen')
stop_words.add('information')
stop_words.add('anrechnen')
stop_words.add('bestehen')
stop_words.add('erlauben')
stop_words.add('dadurch')
stop_words.add('erhoeh')
stop_words.add('kraft')
stop_words.add('verschieden')
stop_words.add('sinnvoll')
stop_words.add('bleiben')
stop_words.add('konkret')
stop_words.add('entsprechen')
stop_words.add('anpassen')
stop_words.add('geak')
stop_words.add('faell')
stop_words.add('nutzen')
stop_words.add('formulierung')
stop_words.add('letzter')
stop_words.add('finden')
stop_words.add('tief')
stop_words.add('tatsaechlich')
stop_words.add('zulassen')
stop_words.add('vorgehen')
stop_words.add('allgemein')
stop_words.add('akzeptieren')
stop_words.add('demselben_text')
stop_words.add('nochmals')
stop_words.add('entzogen_womit')

#time related words
stop_words.add('neujahrstag')
stop_words.add('spaeter')
stop_words.add('heutig')
stop_words.add('monat')
stop_words.add('monate')
stop_words.add('november')
stop_words.add('gleichzeitig')
stop_words.add('heute')
stop_words.add('jahr')
stop_words.add('jaehrliche')
stop_words.add('jaehrlich')
stop_words.add('jaehrlichen')
stop_words.add('jahre')
stop_words.add('januar')
stop_words.add('juni')
stop_words.add('april')
stop_words.add('mai')
stop_words.add('datum')
stop_words.add('zeitlich')
stop_words.add('september')
stop_words.add('kurzfristig')
stop_words.add('gerade')
stop_words.add('heutigen')

stop_words.add('praktisch')
stop_words.add('geraten')
stop_words.add('registrierung')
stop_words.add('gross')

stop_words.add('stoff')
stop_words.add('bau')
stop_words.add('orientieren')
stop_words.add('einreichen')
stop_words.add('bitten')
stop_words.add('schwer')
stop_words.add('buergschaft')
stop_words.add('wesentlich')
stop_words.add('beziehen')
stop_words.add('bestimmen')
stop_words.add('bisherig')
stop_words.add('geplant')
stop_words.add('staerkere')
stop_words.add('bezueglich')
stop_words.add('rp_lt')
stop_words.add('einhalten')
stop_words.add('unser_anliegen')
stop_words.add('diverser')
stop_words.add('groesst')
stop_words.add('erster')
stop_words.add('fluessig')
stop_words.add('beantrag')
stop_words.add('schliessen')
stop_words.add('nachfrage')
stop_words.add('stelle')
stop_words.add('merkmal')
stop_words.add('stuetzen')


stop_words.add('element')
stop_words.add('scheinen')
stop_words.add('aspekt')
stop_words.add('einsetzen')
stop_words.add('igeb')
stop_words.add('kuenftig')
stop_words.add('zuletzt')
stop_words.add('land')
stop_words.add('ermoeglich')
stop_words.add('analog')
stop_words.add('gering')
stop_words.add('bank')
stop_words.add('wille')
stop_words.add('aeusser')
stop_words.add('rasch')
stop_words.add('agvs')
stop_words.add('gemaess')
stop_words.add('tessin')
stop_words.add('beispiel')
stop_words.add('unserer_meinung')
stop_words.add('gallen')
stop_words.add('danken')
stop_words.add('gesuchstellerin')
stop_words.add('geschaeft')
stop_words.add('abkuerzen')
stop_words.add('thema')
stop_words.add('vision')

stop_words.add('regel')
stop_words.add('erwaehnen')
stop_words.add('ermoeglichen')
stop_words.add('einhaltung')
stop_words.add('lehen')
stop_words.add('staatsrat')
stop_words.add('totalrevidiert')
stop_words.add('behoerd')
stop_words.add('artikeln')
stop_words.add('entwurf')
stop_words.add('ordonnance')
stop_words.add('schweizerischen')
stop_words.add('astra')
stop_words.add('behoerden')
stop_words.add('vernehmlassung')
stop_words.add('teilrevision')
stop_words.add('regelunge')
stop_words.add('kantonen')
stop_words.add('verband')
stop_words.add('rev_coz')
stop_words.add('aequivalent')
stop_words.add('groß')
stop_words.add('ausreichend')
stop_words.add('pro_mwh')
stop_words.add('real')
stop_words.add('grosser')
stop_words.add('privat')
stop_words.add('zahl')
stop_words.add('grund')
stop_words.add('ausdruecklich')
stop_words.add('zumindest')
stop_words.add('abkuerzen')
stop_words.add('folge')
stop_words.add('faktor')
stop_words.add('gesuch_hin')
stop_words.add('situation')
stop_words.add('hoeher')
stop_words.add('geeignet')
stop_words.add('form')
stop_words.add('verfuegbar')
stop_words.add('duev')
stop_words.add('stabil')
stop_words.add('ersatzlos')
stop_words.add('empfehlen')
stop_words.add('methodisch')
stop_words.add('meist')
stop_words.add('verlangen')
stop_words.add('puffer')
stop_words.add('allfaellig')
stop_words.add('darum')
stop_words.add('bereiche')
stop_words.add('besteht')
stop_words.add('erhoeht')
stop_words.add('ebenfall')
stop_words.add('net')

stop_words.add('vorgabe')
stop_words.add('nachholen')
stop_words.add('sindienst')
stop_words.add('waehrend')
stop_words.add('anpassungen')
stop_words.add('unzulaessigkeit')
stop_words.add('punkt')
stop_words.add('zusammenhang')
stop_words.add('uebrigen')
stop_words.add('bezug')
stop_words.add('schaffen')
stop_words.add('sachlich')
stop_words.add('entsprechend')
stop_words.add('geprueft')
stop_words.add('antraege')
stop_words.add('opt')
stop_words.add('carbon')
stop_words.add('loesungen')
stop_words.add('indirekte')
stop_words.add('indirekten')
stop_words.add('ziff')
stop_words.add('gas')
stop_words.add('usa')
stop_words.add('us')
stop_words.add('freien')

stop_words.add('umliegenden')
stop_words.add('setzt')
stop_words.add('sgv')
stop_words.add('vfas')
stop_words.add('kmu')
stop_words.add('davon')
stop_words.add('blw')
stop_words.add('haette')

stop_words.add('ausbau')
stop_words.add('vgl')
stop_words.add('vfs')
stop_words.add('menge')
stop_words.add('teilnahme')
stop_words.add('oft')

stop_words.add('franken')
stop_words.add('pro')
stop_words.add('com')
stop_words.add('ab')
stop_words.add('co')
stop_words.add('periode')
stop_words.add('gilt')
stop_words.add('betreiber')
stop_words.add('neuen')
stop_words.add('deren')
stop_words.add('ahr')
stop_words.add('ehs')

stop_words.add('ans')
stop_words.add('zuesaetzlich')

stop_words.add('besteuert')

stop_words.add('entfall')
stop_words.add('fehlenden')
stop_words.add('erheblich')
stop_words.add('einzudaemmen')
stop_words.add('bezahlt')

stop_words.add('anteil')
stop_words.add('je')
stop_words.add('regelung')
stop_words.add('beruecksichtigt')
stop_words.add('erreichen')
stop_words.add('folgende')
stop_words.add('deutlich')

stop_words.add('klimapolitik')
stop_words.add('bescheinigungen')
stop_words.add('instrumente')
stop_words.add('treibhausgas')
stop_words.add('kunden')
stop_words.add('rahmenbedingung')
stop_words.add('betreiber')

stop_words.add('emissionsfaktor')
stop_words.add('emissionsrechte')
stop_words.add('diskrepanz')
stop_words.add('benchmark')
stop_words.add('benchmarks')

stop_words.add('reduzierensziel')
stop_words.add('waermeverbunde')
stop_words.add('waermeverbund')
stop_words.add('waermeverbuende')
stop_words.add('leichtere')
stop_words.add('programm')
stop_words.add('instrument')
stop_words.add('neuwag')
stop_words.add('brennstoff')
stop_words.add('brennstoffe')
stop_words.add('treibstoff')
stop_words.add('treibstoffe')


stop_words.add('technisch')
stop_words.add('zielerreichung')
stop_words.add('grenzwert')
stop_words.add('foerdern')
stop_words.add('anrechnung')
stop_words.add('umrechnung')


stop_words.add('loesung')
stop_words.add('erforderlich')
stop_words.add('verfahren')
stop_words.add('gemeinde')
stop_words.add('beitraege')
stop_words.add('biologisch')

stop_words.add('mitglied')
stop_words.add('weitergefuehrt')
stop_words.add('sorgen')
stop_words.add('ausstoss')
stop_words.add('vergleich')
stop_words.add('verwaltung')
stop_words.add('fossile')
stop_words.add('fossil')

stop_words.add('verkaufen')
stop_words.add('modell')

stop_words.add('neuwagenziels')
stop_words.add('einmalig')
stop_words.add('zweck')
stop_words.add('sicherstellen')
stop_words.add('voraussetzung')
stop_words.add('indessen')
stop_words.add('verpflichten')
stop_words.add('gegensatz')
stop_words.add('laufend')
stop_words.add('betreiben')
stop_words.add('langfristig')
stop_words.add('volle_wirkung')
stop_words.add('inkrafttreten')

stop_words.add('zertifikat')
stop_words.add('abschnitt')
stop_words.add('projeken')
stop_words.add('behandlung')
stop_words.add('zentral')
stop_words.add('problem')
stop_words.add('wahl')
stop_words.add('back_up')
stop_words.add('ziele')
stop_words.add('staat')
stop_words.add('vorgesehenen')
stop_words.add('innerhalb')
stop_words.add('zielvorgabe')
stop_words.add('maßnahmen')
stop_words.add('entsprechende')
stop_words.add('minus')
stop_words.add('anzupassen')
stop_words.add('schweren')
stop_words.add('geschaffen')
stop_words.add('gegeben')
stop_words.add('programmen')
stop_words.add('neuwagenziel')
stop_words.add('abgelehnt')
stop_words.add('definiert')
stop_words.add('fehlt')
stop_words.add('pruefen')
stop_words.add('ig_detailhandel')
stop_words.add('nachvollziehbar')
stop_words.add('nischenziel')
stop_words.add('technische')
stop_words.add('revidierten')
stop_words.add('bleibt')
stop_words.add('grossen')
stop_words.add('zielwert')
stop_words.add('aktuellen')
stop_words.add('betroffenen')
stop_words.add('emissionsbilanz')
stop_words.add('vorgeschlagene')
stop_words.add('vorschrift')
stop_words.add('mittels')
stop_words.add('angesichts')
stop_words.add('bemerkungen')
stop_words.add('it')
stop_words.add('verwendeten')
stop_words.add('groessenordnung')
stop_words.add('werte')
stop_words.add('aeussern')
stop_words.add('netto_null')
stop_words.add('verbesserung')
stop_words.add('schwere')
stop_words.add('zugelassen')
stop_words.add('ff')
stop_words.add('eq_entzogen')
stop_words.add('monaten')
stop_words.add('spricht_diesen')
stop_words.add('moeglichkeiten')
stop_words.add('eingesetzt')
stop_words.add('klimapolitisch')

stop_words.add('waldschweiz')

stop_words.add('erreicht')
stop_words.add('begriff')
stop_words.add('bevoelkerung')
stop_words.add('personen')
stop_words.add('ohnehin')
stop_words.add('zeitraum')
stop_words.add('ausgeschlossen')
stop_words.add('act')
stop_words.add('umkehrung')
stop_words.add('ersten')
stop_words.add('verhindern')
stop_words.add('stark')
stop_words.add('regeln')
stop_words.add('drittel')
stop_words.add('allgemeine')
stop_words.add('jeweiligen')
stop_words.add('bisherigen')
stop_words.add('erhoeht')
stop_words.add('ebenfalls')
stop_words.add('netto')
stop_words.add('erreicht')
stop_words.add('angabe')
stop_words.add('befristete')

stop_words.add('sustainable')
stop_words.add('aviation')
stop_words.add('fuel')

stop_words.add('fordern')
stop_words.add('liegen')
stop_words.add('betreffend')
stop_words.add('berechnung')
stop_words.add('ausstellen')
stop_words.add('erscheinen')
stop_words.add('weit')
stop_words.add('vorsehen')
stop_words.add('korrigieren')
stop_words.add('beginn')

stop_words.add('ausgeloest')
stop_words.add('inhalt')
stop_words.add('anspruch')
stop_words.add('indirekt')
stop_words.add('vermeiden')
stop_words.add('besonders')
stop_words.add('bemerkung')
stop_words.add('nutzung')
stop_words.add('ergaenzen')
stop_words.add('haett')
stop_words.add('finden')
stop_words.add('migros')
stop_words.add('basierend')
stop_words.add('weise')
stop_words.add('ganz')
stop_words.add('uebernahme')
stop_words.add('pauschal')
stop_words.add('information')
stop_words.add('treffen')
stop_words.add('jeweils')
stop_words.add('schlagen')
stop_words.add('verwendung')
stop_words.add('leisten')
stop_words.add('verzichten')
stop_words.add('ueb')
stop_words.add('generell')
stop_words.add('teilnahme_am')
stop_words.add('anhang_ziff')
stop_words.add('darueber_hinaus')
stop_words.add('muesse')
stop_words.add('legen')
stop_words.add('entgegenkommen')
stop_words.add('person')
stop_words.add('vermehrt')
stop_words.add('vorzusehen')
stop_words.add('einfach')
stop_words.add('definieren')
stop_words.add('praxis')
stop_words.add('dessen_staerkt')
stop_words.add('konkret_stellen')

stop_words.add('prospektion')
stop_words.add('satz')
stop_words.add('meinung')
stop_words.add('zwingend')
stop_words.add('alt')
stop_words.add('betrieb')
stop_words.add('auflage')
stop_words.add('entfaellen')
stop_words.add('kommen')
stop_words.add('angedacht')
stop_words.add('anerkennen')
stop_words.add('abfaellen')
stop_words.add('vertreten')
stop_words.add('rechnen')
stop_words.add('vorschlagen')
stop_words.add('emittieren')
stop_words.add('ziehen')
stop_words.add('ergeben')
stop_words.add('kennen')
stop_words.add('beenden')
stop_words.add('eingefuehrt')
stop_words.add('bieten')
stop_words.add('vorgeh')
stop_words.add('haeten')
stop_words.add('anzeigen')
stop_words.add('taetigen')
stop_words.add('fehlen')
stop_words.add('streich')
stop_words.add('runden')
stop_words.add('aufheben')
stop_words.add('voll')
stop_words.add('paris_periode')
stop_words.add('anlaesslich')
stop_words.add('erklaerung')
stop_words.add('ergaenzung')
stop_words.add('anmerkung')
stop_words.add('kriterium')
stop_words.add('vollzug')
stop_words.add('allein_gut')
stop_words.add('liefern')
stop_words.add('fast_getragen')
stop_words.add('dabei_hand')
stop_words.add('sei_analog')
stop_words.add('haelt_lediglich')
stop_words.add('quasi')
stop_words.add('system')
stop_words.add('unterschrift')
stop_words.add('kyoto_protokoll')
stop_words.add('ausnahme')
stop_words.add('maßnahme')
stop_words.add('massnahme')
stop_words.add('entwicklung')
stop_words.add('kunde')
stop_words.add('pro_importeur')
stop_words.add('einnahme')
stop_words.add('kombination')
stop_words.add('bedauern')
stop_words.add('interesse')
stop_words.add('einzig')
stop_words.add('abtretung')
stop_words.add('zaehlen')
stop_words.add('genau')
stop_words.add('umgehung')
stop_words.add('jungunternehmen')
stop_words.add('uvek_zuhande')
stop_words.add('energie_urek')
stop_words.add('per_anfang')
stop_words.add('angestrebt')
stop_words.add('uebernehmen')
stop_words.add('glaubhaft')
stop_words.add('einfuehrung')
stop_words.add('berechnen')
stop_words.add('gleichwertig')
stop_words.add('nachweis')
stop_words.add('aufbau')
stop_words.add('ausschliessen')
stop_words.add('festgelegt')
stop_words.add('verkauf')
stop_words.add('antrieb')
stop_words.add('einfuehrung')
stop_words.add('erzielung')

stop_words.add('testverfahren')
stop_words.add('vvea')
stop_words.add('hs')
stop_words.add('resp')
stop_words.add('taetig')
stop_words.add('verleztung')
stop_words.add('anliegen')
stop_words.add('erhebliche')
stop_words.add('kalkstein')
stop_words.add('mechanismus')
stop_words.add('berechnet')
stop_words.add('direkten')
stop_words.add('kostenlos')
stop_words.add('gelten')
stop_words.add('anhand')
stop_words.add('gerne')
stop_words.add('spricht')
stop_words.add('aufgehoben')
stop_words.add('wegfall')
stop_words.add('momentan')
stop_words.add('eher')
stop_words.add('gehen')

stop_words.add('netze')
stop_words.add('netzen')
stop_words.add('abwaerme')
stop_words.add('waerme')
stop_words.add('erst')
stop_words.add('ig')
stop_words.add('ets')
stop_words.add('allerdings')
stop_words.add('entsprechenden')
stop_words.add('erreichung')
stop_words.add('erachten')
stop_words.add('leichte')
stop_words.add('waeren')
stop_words.add('angepasst')
stop_words.add('erfuellen')
stop_words.add('erlaubt')
stop_words.add('recht')
stop_words.add('grundsaetzlich')
stop_words.add('vo')
stop_words.add('seitens')
stop_words.add('direkt')
stop_words.add('einzelnen')
stop_words.add('allgemeines')
stop_words.add('gar')

stop_words.add('entspricht')
stop_words.add('gwr')
stop_words.add('bestehend')
stop_words.add('stellen')
stop_words.add('moeglichst')

stop_words.add('neuen')
stop_words.add('daher')
stop_words.add('sektor')
stop_words.add('gegenueber')
stop_words.add('einsatz')
stop_words.add('lit')
stop_words.add('gruende')
stop_words.add('zb')
stop_words.add('projekt')
stop_words.add('moeglichkeit')
stop_words.add('erhoehung')
stop_words.add('swiss')
stop_words.add('nehmen')
stop_words.add('beitrag')
stop_words.add('to')
stop_words.add('wurden')
stop_words.add('streichen')
stop_words.add('frist')
stop_words.add('weniger')
stop_words.add('rev')
stop_words.add('coz')
stop_words.add('bisher')
stop_words.add('gramm')
stop_words.add('neue')
stop_words.add('duerfen')
stop_words.add('zudem')
stop_words.add('somit')
stop_words.add('verwendet')
stop_words.add('unternehmen')
stop_words.add('rahmen')
stop_words.add('ausgestellt')
stop_words.add('plug')
stop_words.add('ersatz')
stop_words.add('km')
stop_words.add('emissionen')
stop_words.add('zielvorgaben')
stop_words.add('begruendung')
stop_words.add('strom')
stop_words.add('ccs')
stop_words.add('ccu')
stop_words.add('projekten')
stop_words.add('betreffenden')
stop_words.add('tonnen')
stop_words.add('moeglich')
stop_words.add('erfuellung')
stop_words.add('erlaeuternde')
stop_words.add('erfuellung')
stop_words.add('umfang')
stop_words.add('allein')
stop_words.add('explizit')
stop_words.add('buchstabe')
stop_words.add('hinweis')
stop_words.add('sollten')
stop_words.add('thg')
stop_words.add('sinne')
stop_words.add('mio')

stop_words.add('folgt')
stop_words.add('fall')
stop_words.add('neu')
stop_words.add('seite')
stop_words.add('spaetestens')
stop_words.add('bfs')
stop_words.add('ad')
stop_words.add('falls')
stop_words.add('pariser')
stop_words.add('per')
stop_words.add('darf')
stop_words.add('immer')
stop_words.add('fall')
stop_words.add('fuehren')
stop_words.add('dabei')
stop_words.add('climeworks')
stop_words.add('eg')
stop_words.add('lassen')
stop_words.add('geltende')
stop_words.add('erscheint')
stop_words.add('weshalb')
stop_words.add('eq')
stop_words.add('zeitpunkt')
stop_words.add('durchgefuehrten')
stop_words.add('umso')
stop_words.add('begruendet')
stop_words.add('ue')
stop_words.add('folgenden')
stop_words.add('pflicht')
stop_words.add('stellt')
stop_words.add('liegt')
stop_words.add('erzielte')
stop_words.add('macht')
stop_words.add('zieljahr')
stop_words.add('entzogen')
stop_words.add('geltenden')
stop_words.add('zwei')
stop_words.add('erfuellt')
stop_words.add('lediglich')
stop_words.add('gibt')
stop_words.add('mindestens')
stop_words.add('beantragen')
stop_words.add('angerechnet')
stop_words.add('unveraendert')
stop_words.add('ende')

stop_words.add('geltende')
stop_words.add('durchgefuehrten')
stop_words.add('stellung')
stop_words.add('fuehrt')
stop_words.add('vorgeschlagen')
stop_words.add('gegruesst')
stop_words.add('fckw')
stop_words.add('fdp')
stop_words.add('mitgliedstaat')
stop_words.add('ie')
stop_words.add('de')
stop_words.add('kunst')
stop_words.add('maximal')
stop_words.add('bestimmung')
stop_words.add('massnahmen')
stop_words.add('anforderung')
stop_words.add('darauf')

stop_words.add('aenderung')
stop_words.add('umgesetzt')
stop_words.add('auswirkung')
stop_words.add('hinaus')
stop_words.add('anwendung')
stop_words.add('unserer')
stop_words.add('weiterhin')
stop_words.add('trotz')
stop_words.add('moechten')
stop_words.add('bereich')


stop_words.add('kapitel')
stop_words.add('wenig')
stop_words.add('phasing')
stop_words.add('erhoehen')
stop_words.add('sicht')
stop_words.add('zuteilung')
stop_words.add('core')
stop_words.add('ziel')
stop_words.add('null')
stop_words.add('aendern')
stop_words.add('ag')
stop_words.add('zug')
stop_words.add('weiteren')
stop_words.add('la')
stop_words.add('tcs')
stop_words.add('vsgp')
stop_words.add('projet')
stop_words.add('en')
stop_words.add('les')
stop_words.add('ch')
stop_words.add('nous')
stop_words.add('kaum')
stop_words.add('seit')
stop_words.add('wert')
stop_words.add('dar')
stop_words.add('back')
stop_words.add('luecken')
stop_words.add('que')
stop_words.add('sur')
stop_words.add('hohen')
stop_words.add('klima')
stop_words.add('baubranche')
stop_words.add('dafuer')
stop_words.add('faktisch')
stop_words.add('gesamthaft')
stop_words.add('basis')
stop_words.add('regen')
stop_words.add('sicht')
stop_words.add('anteil')
stop_words.add('vorliegenden')
stop_words.add('wichtig')
stop_words.add('zusaetzlichen')
stop_words.add('nefz')
stop_words.add('chf')
stop_words.add('ebenfalls')
stop_words.add('viele')
stop_words.add('kva')
stop_words.add('millionen')
stop_words.add('infrawatt')

stop_words.add('hand')
stop_words.add('sogar')
stop_words.add('halten')
stop_words.add('zusaetzlichkeit')
stop_words.add('zusaetzliche')
stop_words.add('reduzierenen')
stop_words.add('reduzieren')
stop_words.add('reduziert')
stop_words.add('klimaschutz') # high occurence in all - strong climate policy
stop_words.add('nachhaltigen') # klimaschutz

stop_words.add('internationale')
stop_words.add('international') # combination with senkenleistung, landwirtschaft, beimischquote 
stop_words.add('inland')
stop_words.add('ausland')

stop_words.add('mittel') # subsidies
stop_words.add('foerderung')
stop_words.add('sockelbeitrag') # gehört zu finanzhilfe, mittel ect

stop_words.add('abgabe') # all co2-abgabe? topic of high frequ. 
# beimischquote 
# verkehr, fahrzeuge, ersatzneubar - treibstoff?, synthetisch 

stop_words.add('verkehr')
stop_words.add('hersteller')
stop_words.add('flugverkehr') # high frequency of terms like traffic, airtraffic
stop_words.add('luftfahrt')
stop_words.add('luftverkehr')
stop_words.add('oeffentlichen') # verkehr ? subventionen

stop_words.add('fahrzeuge') # one of most frequent words
stop_words.add('gebaeude') # one of most frequent words
stop_words.add('energetisch')

stop_words.add('erneuerbare')
stop_words.add('erneuerbarer')
stop_words.add('fossilen') # high occurance of diff. fuels, energy sources
stop_words.add('methan')
stop_words.add('synthetisch')
stop_words.add('wasserstoff')

stop_words.add('begruessen')
stop_words.add('begruesst')


# not meaningful
stop_words.add('innen')
stop_words.add('sab')
stop_words.add('greenpeace')
stop_words.add('swisscleantech')
stop_words.add('zuerich_konto')
stop_words.add('produktion')
stop_words.add('gesetzt')
stop_words.add('bundes')
stop_words.add('umstellung')
stop_words.add('www')
stop_words.add('danken_ihnen')
stop_words.add('paris')
stop_words.add('kopf')
stop_words.add('ter')
stop_words.add('legt')
stop_words.add('kantone_legen')
stop_words.add('braucht')
stop_words.add('heimatschutz') # with term regarding gebäude, solarenergy
stop_words.add('importeure')
stop_words.add('schlaegt')
stop_words.add('staedteverband')
stop_words.add('grundsatz')
stop_words.add('einnahmen')
stop_words.add('lsva')
stop_words.add('oev')
stop_words.add('gruenen')
stop_words.add('jungen_gruenen')
stop_words.add('produkte')
stop_words.add('neben')
stop_words.add('bern')
stop_words.add('dezember')
stop_words.add('biomasse_suisse')
stop_words.add('sia')
stop_words.add('vse')
stop_words.add('sieht')
stop_words.add('voev')
stop_words.add('gesetzesentwurf')
stop_words.add('atmosphaere')
stop_words.add('aeesuisse')
stop_words.add('bzw_thg')
stop_words.add('travail_suisse')
stop_words.add('erstmals')
stop_words.add('haelfte')
stop_words.add('ausserdem')
stop_words.add('schon')
stop_words.add('satom_sa')
stop_words.add('fer')
stop_words.add('raiffeisen')
stop_words.add('erstellung')
stop_words.add('april_swiss')
stop_words.add('kkw')
stop_words.add('nart')
stop_words.add('sbb')
stop_words.add('fms')
#stop_words.add('')

print(stop_words)




from setuptools import setup

setup(name='EnStp_de',
      version='1.0.0',
      description='german stopwords for energy policy for content analysis based on LDA topic modeling',
      author='Meixi Zhang',
      packages=['EnStp_de'],
      zip_safe=False)
